==> qtah-qt5-0.3.0.tar.gz: qtah-qt5-0.3.0/src/Graphics/UI/Qtah/Widgets/QSpinBox.hs <==
{-# LANGUAGE CPP, FlexibleContexts, FlexibleInstances, GeneralizedNewtypeDeriving, MultiParamTypeClasses, ScopedTypeVariables, TypeSynonymInstances, UndecidableInstances #-}
#if !MIN_VERSION_base(4,8,0)
{-# LANGUAGE OverlappingInstances #-}
#endif

---------- GENERATED FILE, EDITS WILL BE LOST ----------

{-# LANGUAGE NoMonomorphismRestriction #-}

module Graphics.UI.Qtah.Widgets.QSpinBox (
  QSpinBoxValue (..),
  QSpinBoxConstPtr (..),
  QSpinBoxPtr (..),
  QSpinBoxConst,
  QSpinBox,
  castConst,
  cast,
  downCastConst,
  downCast,
  new,
  newWithParent,
  cleanText,
  displayIntegerBase,
  maximum,
  minimum,
  prefix,
  setDisplayIntegerBase,
  setMaximum,
  setMinimum,
  setPrefix,
  setRange,
  setSingleStep,
  setSuffix,
  setValue,
  singleStep,
  suffix,
  value,
  valueChangedIntSignal,
  valueChangedStringSignal,
  ) where

import Graphics.UI.Qtah.Generated.Widgets.QSpinBox
import Graphics.UI.Qtah.Internal.Listener
import qualified Graphics.UI.Qtah.Signal as QtahSignal
import Prelude ()
import qualified Prelude as HoppyP
import qualified Prelude as QtahP


castConst = toQSpinBoxConst
cast = toQSpinBox
downCastConst = downToQSpinBoxConst
downCast = downToQSpinBox

valueChangedIntSignal :: (QSpinBoxPtr object) => QtahSignal.Signal object (HoppyP.Int -> HoppyP.IO ())
valueChangedIntSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerInt_new fn'
    listenerInt_connectListener listener' object' "2valueChanged(int)"
  , QtahSignal.internalName = "QSpinBox::valueChanged (ListenerInt)"
  }

valueChangedStringSignal :: (QSpinBoxPtr object) => QtahSignal.Signal object (QtahP.String -> HoppyP.IO ())
valueChangedStringSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerQString_new fn'
    listenerQString_connectListener listener' object' "2valueChanged(QString)"
  , QtahSignal.internalName = "QSpinBox::valueChanged (ListenerQString)"
  }

==> qtah-qt5-0.8.0.tar.gz: qtah-qt5-0.8.0/src/Graphics/UI/Qtah/Widgets/QSpinBox.hs <==
{-# LANGUAGE FlexibleContexts, FlexibleInstances, ForeignFunctionInterface, MonoLocalBinds, MultiParamTypeClasses, ScopedTypeVariables, TypeSynonymInstances, UndecidableInstances #-}
---------- GENERATED FILE, EDITS WILL BE LOST ----------

{-# LANGUAGE NoMonomorphismRestriction #-}

module Graphics.UI.Qtah.Widgets.QSpinBox (
  QSpinBoxValue (..),
  QSpinBoxConstPtr (..),
  QSpinBoxPtr (..),
  QSpinBoxConst,
  QSpinBox,
  castConst,
  cast,
  downCastConst,
  downCast,
  new,
  newWithParent,
  cleanText,
  displayIntegerBase,
  emitValueChangedInt,
  emitValueChangedString,
  maximum,
  minimum,
  prefix,
  setDisplayIntegerBase,
  setMaximum,
  setMinimum,
  setPrefix,
  setRange,
  setSingleStep,
  setSuffix,
  setValue,
  singleStep,
  suffix,
  value,
  valueChangedIntSignal,
  valueChangedStringSignal,
  ) where

import qualified Foreign.Hoppy.Runtime as QtahFHR
import Graphics.UI.Qtah.Generated.Widgets.QSpinBox
import Graphics.UI.Qtah.Internal.Listener
import qualified Graphics.UI.Qtah.Signal as QtahSignal
import Prelude (($), (>>))
import qualified Prelude as HoppyP
import qualified Prelude as QtahP


castConst = toQSpinBoxConst
cast = toQSpinBox
downCastConst = downToQSpinBoxConst
downCast = downToQSpinBox

valueChangedIntSignal :: (QSpinBoxPtr object) => QtahSignal.Signal object (HoppyP.Int -> HoppyP.IO ())
valueChangedIntSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerInt_new object' "2valueChanged(int)" fn'
    valid' <- listenerInt_isValid listener'
    if valid'
      then QtahP.fmap QtahP.Just $ QtahSignal.internalMakeConnection listener'
      else QtahFHR.delete listener' >> QtahP.return QtahP.Nothing
  , QtahSignal.internalName = "QSpinBox::valueChanged (ListenerInt)"
  }

valueChangedStringSignal :: (QSpinBoxPtr object) => QtahSignal.Signal object (QtahP.String -> HoppyP.IO ())
valueChangedStringSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerQString_new object' "2valueChanged(QString)" fn'
    valid' <- listenerQString_isValid listener'
    if valid'
      then QtahP.fmap QtahP.Just $ QtahSignal.internalMakeConnection listener'
      else QtahFHR.delete listener' >> QtahP.return QtahP.Nothing
  , QtahSignal.internalName = "QSpinBox::valueChanged (ListenerQString)"
  }
